Rename hexdump to hexdump_write.

It's a static function anyway so it doesn't affect anything and it's
colliding with a debugging function on one platform.

Change-Id: Iae0595cce7cb2bdd4c56217f6f1de51ff3134a8b
Reviewed-on: https://boringssl-review.googlesource.com/2630
Reviewed-by: David Benjamin <davidben@chromium.org>
Reviewed-by: Adam Langley <agl@google.com>
diff --git a/crypto/bio/hexdump.c b/crypto/bio/hexdump.c
index d31d3a4..61a2673 100644
--- a/crypto/bio/hexdump.c
+++ b/crypto/bio/hexdump.c
@@ -81,9 +81,10 @@
   return b;
 }
 
 /* hexdump adds |len| bytes of |data| to the current hex dump described by
  * |ctx|. */
-static int hexdump(struct hexdump_ctx *ctx, const uint8_t *data, size_t len) {
+static int hexdump_write(struct hexdump_ctx *ctx, const uint8_t *data,
+                         size_t len) {
   size_t i;
   char buf[10];
   unsigned l;
@@ -182,7 +183,7 @@
   ctx.bio = bio;
   ctx.indent = indent;
 
-  if (!hexdump(&ctx, data, len) || !finish(&ctx)) {
+  if (!hexdump_write(&ctx, data, len) || !finish(&ctx)) {
     return 0;
   }
@@ -81,9 +81,10 @@
 }
 
-/* hexdump adds |len| bytes of |data| to the current hex dump described by
+/* hexdump_write adds |len| bytes of |data| to the current hex dump described by
  * |ctx|. */